{ config, pkgs, ... }:

{
  imports = [ # Include the results of the hardware scan.
    ./hardware-configuration.nix

    # GUI
    ../../modules/system/gui/steam.nix
    ../../modules/system/gui/hyprland.nix
    ../../modules/system/gui/thunar.nix

    # CLI
    ../../modules/system/cli/common.nix
    ../../modules/system/cli/podman.nix

    # Hardware
    ../../modules/system/hardware/firewall.nix
    ../../modules/system/hardware/garbage-collection.nix
    ../../modules/system/hardware/locale.nix
    ../../modules/system/hardware/nvidia.nix

    # Containers
    # ../../modules/containers/adguard.nix
    # ../../modules/containers/caddy.nix
  ];

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
    ];
  };


  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
  };

  networking.hostName = "xv-desktop"; # Define your hostname.
  networking.interfaces.enp7s0.wakeOnLan.enable = true;

  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" "fuse" ];
  };

  services.openssh.enable = true;

  # boot.kernelPackages = pkgs.linuxPackages_latest;

  # sunshine
  services.sunshine = {
    enable = true;
    autoStart = true;
    capSysAdmin = true;
    openFirewall = true;
  };

  system.stateVersion = "24.05";

}
