{ config, pkgs, ... }:

{
  imports = [ # Include the results of the hardware scan.
    ./hardware-configuration.nix

    # CLI
    ../../modules/system/cli/common.nix
    ../../modules/system/cli/podman.nix

    # Hardware
    ../../modules/system/hardware/firewall.nix
    ../../modules/system/hardware/garbage-collection.nix
    ../../modules/system/hardware/locale.nix
  ];

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
      "https://cache.nixos.org/"
    ];
    trusted-public-keys = [
      "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
    ];
  };

  # Bootloader
  boot.loader.grub = {
    enable = true;
    device = "/dev/sda";
    useOSProber = true;
  };

  # Networking
  networking.networkmanager.enable = true;

  networking.firewall = {
    allowedTCPPorts = [ 80 443 1080 ];
    allowedUDPPorts = [ 53 ];
  };

  # Configure user
  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" "fuse" ];
  };

  system.stateVersion = "24.05";

}
